from loafer.message_translators import AbstractMessageTranslator as LoaferAbstractMessageTranslator
from loafer.message_translators import logger

logger.name = __name__


class AbstractMessageTranslator(LoaferAbstractMessageTranslator):
    pass
